@@ -637,9 +637,14 @@ class Device:
 
         end = time.monotonic() + timeout
         while True:
+            self.bus.reset()
+            await epyqlib.utils.twisted.sleep(1)
             try:
                 await a_parameter_that_can_be_read.get()
-            except epyqlib.twisted.nvs.RequestTimeoutError:
+            except (
+                epyqlib.twisted.nvs.RequestTimeoutError,
+                epyqlib.twisted.nvs.SendFailedError,
+            ):
                 if time.monotonic() > end:
                     raise
                 continue
@@ -919,7 +924,7 @@ class SunSpecDevice:
             + " removed in the future. Use SunSpecDevice.load_rtu()"
             + " or SunSpecDevice.load_tcp() instead."
         )
-        warnings.warn(message=message, category=warnings.DeprecationWarning)
+        warnings.warn(message=message, category=DeprecationWarning)
 
         with epcsunspecdemo.utils.fresh_smdx_path(self.model_path):
             self.device = sunspec.core.client.SunSpecClientDevice(
