@@ -7,11 +7,11 @@ import epyqlib.cmemoryparser
 
 here = pathlib.Path(__file__).parent
 
-outs = tuple(sorted((here/'outs').glob('*.out')))
+outs = tuple(sorted((here / "outs").glob("*.out")))
 
 
 @pytest.mark.parametrize(
-    argnames='path',
+    argnames="path",
     argvalues=outs,
     ids=[out.name for out in outs],
 )
